@@ -1,12 +1,11 @@
+import attr
 from datetime import datetime
 from typing import Optional
 
-import attr
-
 
 @attr.dataclass(frozen=True, slots=True)
 class JenisGugus:
-    jenis_gugus_id: str
+    jenis_gugus_id: int
     jenis_gugus: str
     create_date: datetime
     last_update: datetime
