@@ -1,12 +1,11 @@
+import attr
 from datetime import datetime
 from typing import Optional
 
-import attr
-
 
 @attr.dataclass(frozen=True, slots=True)
 class JenisPtk:
-    jenis_ptk_id: str
+    jenis_ptk_id: int
     jenis_ptk: str
     guru_kelas: str
     guru_matpel: str
@@ -24,3 +23,6 @@ class JenisPtk:
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
+
+    def __str__(self):
+        return self.jenis_ptk
