@@ -17,7 +17,7 @@ class RombonganBelajar:
     nama: str
     ptk_id: UUID
     moving_class: str
-    jenis_rombel: str
+    jenis_rombel: int
     sks: str
     tanggal_mulai: date
     tanggal_selesai: date
@@ -37,7 +37,7 @@ class RombonganBelajar:
     pembelajaran_count: int
     anggota_rombel_count: int
     jenis_rombel_str: str
-    jurusan_id: str
+    jurusan_id: int
     jurusan_id_str: str
     tingkat_pendidikan_id_str: str
     semester_id: str = __semester__
