@@ -6,12 +6,12 @@ import attr
 @attr.dataclass
 class SekolahPaud:
     sekolah_id: str
-    kategori_tk_id: str
-    klasifikasi_lembaga_id: str
+    kategori_tk_id: int
+    klasifikasi_lembaga_id: int
     sumber_dana_sekolah_id: str
-    fasilitas_layanan_id: str
+    fasilitas_layanan_id: int
     jadwal_pmtas: str
-    lembaga_pengangkat_id: str
+    lembaga_pengangkat_id: int
     jadwal_ddtk: str
     freq_parenting: str
     bentuk_lembaga_id: str
